==> nextcloud-23.0.7.tgz: nextcloud/apps/password_policy/l10n/sv.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Lösenordet har gått ut, använd knapp glömt lösenordet för att återställa",
    "Password must not have been used recently before." : "Lösenordet får inte nyligen ha används.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Lösenord är bland de 1 000 000 mest vanliga. Vänligen ändra till ett unikt.",
    "Password is present in compromised password list. Please choose a different password." : "Lösenordet finns i en läckt lösenordslista. Vänligen välj ett annat lösenord.",
    "Password needs to be at least %s characters long." : "Lösenordet måste vara minst %s tecken långt.",
    "Password needs to contain at least one numeric character." : "Lösenord behöver innehålla åtminstone en siffra.",
    "Password needs to contain at least one special character." : "Lösenord behöver innehålla minst ett specialtecken.",
    "Password needs to contain at least one lower and one upper case character." : "Lösenord behöver innehålla åtminstone en liten och en stor bokstav.",
    "Password policy" : "Lösenordsregler",
    "Allows admins to configure a password policy" : "Tillåter administratörer att konfigurera en lösenordspolicy",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Tillåter administratören att definiera vissa villkor för lösenord, t.ex. att kräva minsta längd",
    "Saved" : "Sparad",
    "Minimum password length" : "Minsta lösenordslängd",
    "User password history" : "Lösenordshistorik",
    "Number of days until user password expires" : "Antal dagar tills lösenordet går ut",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Antalet inloggningsförsök innan användarkontot blockeras (0 för obegränsat)",
    "Forbid common passwords" : "Förbjud de vanligaste lösenorden",
    "Enforce upper and lower case characters" : "Kräv stor och liten bokstav i lösenordet",
    "Enforce numeric characters" : "Kräv en siffra i lösenordet",
    "Enforce special characters" : "Kräv specialtecken i lösenordet",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontrollera lösenordet mot listan med läckta lösenord från haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Denna kontroll skapar en hash av lösenordet och skickar de 5 första tecknen i denna hash till haveibeenpwned.com för att hämta en lista över alla hash som börjar med dessa. Sedan kontrolleras om lösenords-hashet finns i resultatuppsättningen på Nextcloud.",
    "Unknown error" : "Okänt fel",
    "Minimal length has to be a non negative number" : "Minsta längden måste vara ett icke-negativt tal",
    "History size has to be a non negative number" : "Historikstorlek måste vara ett icke-negativt tal",
    "Expiration days have to be a non negative number" : "Dagar till utgång måste vara ett icke-negativt tal",
    "Maximum login attempts have to be a non negative number" : "Maximala inloggningsförsök måste vara ett icke-negativt tal"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.12p0.tgz: nextcloud/apps/password_policy/l10n/sv.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Lösenordet har gått ut, använd knapp glömt lösenordet för att återställa",
    "Password must not have been used recently before." : "Lösenordet får inte nyligen ha används.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Lösenord är bland de 1 000 000 mest vanliga. Vänligen ändra till ett unikt.",
    "Password is present in compromised password list. Please choose a different password." : "Lösenordet finns i en läckt lösenordslista. Vänligen välj ett annat lösenord.",
    "Password needs to be at least %s characters long." : "Lösenordet måste vara minst %s tecken långt.",
    "Password needs to contain at least one numeric character." : "Lösenord behöver innehålla åtminstone en siffra.",
    "Password needs to contain at least one special character." : "Lösenord behöver innehålla minst ett specialtecken.",
    "Password needs to contain at least one lower and one upper case character." : "Lösenord behöver innehålla åtminstone en liten och en stor bokstav.",
    "Password policy" : "Lösenordsregler",
    "Allows admins to configure a password policy" : "Tillåter administratörer att konfigurera en lösenordspolicy",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Tillåter administratören att definiera vissa villkor för lösenord, t.ex. att kräva minsta längd",
    "Saved" : "Sparad",
    "Minimum password length" : "Minsta lösenordslängd",
    "User password history" : "Lösenordshistorik",
    "Number of days until user password expires" : "Antal dagar tills lösenordet går ut",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Antalet inloggningsförsök innan användarkontot blockeras (0 för obegränsat)",
    "Forbid common passwords" : "Förbjud de vanligaste lösenorden",
    "Enforce upper and lower case characters" : "Kräv stor och liten bokstav i lösenordet",
    "Enforce numeric characters" : "Kräv en siffra i lösenordet",
    "Enforce special characters" : "Kräv specialtecken i lösenordet",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontrollera lösenordet mot listan med läckta lösenord från haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Denna kontroll skapar en hash av lösenordet och skickar de 5 första tecknen i denna hash till haveibeenpwned.com för att hämta en lista över alla hash som börjar med dessa. Sedan kontrolleras om lösenords-hashet finns i resultatuppsättningen på Nextcloud.",
    "Unknown error" : "Okänt fel",
    "Minimal length has to be a non negative number" : "Minsta längden måste vara ett icke-negativt tal",
    "History size has to be a non negative number" : "Historikstorlek måste vara ett icke-negativt tal",
    "Expiration days have to be a non negative number" : "Dagar till utgång måste vara ett icke-negativt tal",
    "Maximum login attempts have to be a non negative number" : "Maximala inloggningsförsök måste vara ett icke-negativt tal",
    "Error while saving" : "Kunde inte spara"
},
"nplurals=2; plural=(n != 1);");
